@@ -1,6 +1,7 @@
+# -*- coding: ascii -*-
 #
 #  bln.py - a easyballoon compatible Saori module for ninix
-#  Copyright (C) 2002, 2003 by Shyouzou Sugitani <shy@debian.or.jp>
+#  Copyright (C) 2002-2005 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -15,13 +16,10 @@
 # - \l
 
 import os
-import string
-import StringIO
 import random
 import math
 import time
 import sys
-import codecs
 
 if os.environ.has_key('DISPLAY'):
     if not sys.modules.has_key('gtk'):
@@ -31,24 +29,29 @@ if os.environ.has_key('DISPLAY'):
         except ImportError:
             pass
     import gtk
+    import gobject
     import pango
+    import ninix.pix
 else:
     gtk = None
 
-import ninix.pix
 import ninix.script
+from ninix.dll import SAORI
+
+class Saori(SAORI):
 
-class Saori:
     def __init__(self):
-	self.loaded = 0
+        SAORI.__init__(self)
         self.blns = {}
-        self.sakura = None
-    def use_sakura(self, sakura):
-        self.sakura = sakura
+        self.__ghost = None
+
+    def need_ghost_backdoor(self, ghost):
+        self.__ghost = ghost
+
     def load(self, dir=os.curdir):
         self.dir = dir
         result = 0
-        if not self.sakura or not gtk:
+        if not self.__ghost or not gtk:
             pass
         elif self.loaded:
 	    result = 2
@@ -58,42 +61,41 @@ class Saori:
                 self.loaded = 1
                 result = 1
 	return result
+
     def read_bln_txt(self, dir):
         blns = {}
         try:
             file = open(os.path.join(dir, 'bln.txt'), 'r')
             data = {}
             name = ''
-            while 1:
-                line = file.readline()
-                if not line:
-                    if name:
-                        blns[name] = (data, {})
-                    break # EOF
-                line = string.strip(line)
+            for line in file:
+                line = line.strip()
                 if not line:
                     continue
                 if line[:2] == '//':
                     continue
-                start = string.find(line, '[')
+                start = line.find('[')
                 if start >= 0:
                     if name:
                         blns[name] = (data, {})
                     data = {}
-                    end = string.find(line, ']')
+                    end = line.find(']')
                     if end < 0:
                         end = len(line)
                     name = line[start+1:end]
                 else:
-                    comma = string.find(line, ',')
+                    comma = line.find(',')
                     if comma >= 0:
-                        key = string.strip(line[:comma])
-                        value = string.strip(line[comma+1:])
+                        key = line[:comma].strip()
+                        value = line[comma+1:].strip()
                         data[key] = value
+            if name:
+                blns[name] = (data, {})
             return blns
         except:
             return None
-    def unload(self):
+
+    def finalize(self):
         for name in self.blns.keys():
             data, bln = self.blns[name]
             for bln_id in bln.keys():
@@ -101,12 +103,10 @@ class Saori:
                     bln[bln_id].destroy()
                     del bln[bln_id]
         self.blns = {}
-        self.loaded = 0
         return 1
+
     def request(self, req):
         type, argument = self.evaluate_request(req)
-        header = StringIO.StringIO(req)
-        line = header.readline()
         if not type:
             return 'SAORI/1.0 400 Bad Request\r\n\r\n'
         elif type == 'GET Version':
@@ -148,7 +148,7 @@ class Saori:
                     del bln[bln_id]
                 if text:
                     if update == 0 or not bln.has_key(bln_id):
-                        bln[bln_id] = Balloon(self.sakura, self.dir, data, text,
+                        bln[bln_id] = Balloon(self.__ghost, self.dir, data, text,
                                               offset_x, offset_y, name, bln_id)
                     else:
                         bln[bln_id].update_script(text, update)
@@ -162,53 +162,12 @@ class Saori:
                         del bln[bln_id]
                         self.blns[name] = (data, {})
             return 'SAORI/1.0 204 No Content\r\n\r\n'
-    def evaluate_request(self, req):
-        type = None
-        argument = []
-        charset = 'Shift_JIS' # default
-        header = StringIO.StringIO(req)
-        line = header.readline()
-        if not line:
-            return type, argument
-        if line[-1] == '\n':
-            line = line[:-1]
-        line = string.strip(line)
-        if not line:
-            return type, argument
-        for request in ['EXECUTE', 'GET Version']:
-            if line[:len(request)] == request:
-                type = request
-                break
-        while 1:
-            line = header.readline()
-            if not line:
-                break # EOF
-            if line[-1] == '\n':
-                line = line[:-1]
-            line = string.strip(line)
-            if not line:
-                continue
-            colon = string.find(line, ':')
-            if colon >= 0:
-                key = string.strip(line[:colon])
-                value = string.strip(line[colon+1:])
-                if key == 'Charset':
-                    try:
-                        codecs.lookup(value)
-                    except:
-                        sys.stderr.write("Unsupported charset %s" % repr(charset))
-                    else:
-                        charset = value
-                elif key[:8] == 'Argument':
-                    argument.append(unicode(value, charset, 'replace'))
-                else:
-                    continue
-        return type, argument
 
 class Balloon:
-    def __init__(self, sakura, dir, data, text, offset_x, offset_y, name, bln_id):
+
+    def __init__(self, ghost, dir, data, text, offset_x, offset_y, name, bln_id):
         self.dir = dir
-        self.sakura = sakura
+        self.__ghost = ghost
         self.dragged = 0
         self.name = name
         self.id = bln_id
@@ -259,20 +218,22 @@ class Balloon:
             (self.position == 'kero' and self.direction1)) and \
             data.has_key('skin.right'):
             path = os.path.join(self.dir,
-                                string.replace(data['skin.right'],
-                                               '\\', '/'))
+                                data['skin.right'].replace('\\', '/'))
         elif (self.position == 'sakura' or self.position == 'kero') and \
              data.has_key('skin.left'):
             path = os.path.join(self.dir,
-                                string.replace(data['skin.left'],
-                                               '\\', '/'))
+                                data['skin.left'].replace('\\', '/'))
         elif data.has_key('skin'):
             path = os.path.join(self.dir,
-                                string.replace(data['skin'],
-                                               '\\', '/'))
+                                data['skin'].replace('\\', '/'))
         else:
             self.destroy()
-        image, mask = ninix.pix.create_pixmap_from_file(path)
+            return None
+        try:
+            image, mask = ninix.pix.create_pixmap_from_file(path)
+        except:
+            self.destroy()
+            return None
         self.x = 0
         self.y = 0 + self.get_sakura_status('getTopMargin')
         w, h = image.get_size()
@@ -320,20 +281,20 @@ class Balloon:
         if data.has_key('offset.x'):
             if (self.position == 'sakura' and not self.direction0) or \
                (self.position == 'kero' and not self.direction1):
-                self.x = self.x - int(data['offset.x'])
+                self.x -= int(data['offset.x'])
             else:
-                self.x = self.x + int(data['offset.x'])
+                self.x += int(data['offset.x'])
         if data.has_key('offset.y'):
-            self.y = self.y + int(data['offset.y'])
+            self.y += int(data['offset.y'])
         if data.has_key('offset.random'):
-            self.x = self.x + int(data['offset.random']) * random.randrange(-1, 2)
-            self.y = self.y + int(data['offset.random']) * random.randrange(-1, 2)
+            self.x += int(data['offset.random']) * random.randrange(-1, 2)
+            self.y += int(data['offset.random']) * random.randrange(-1, 2)
         if (self.position == 'sakura' and not self.direction0) or \
            (self.position == 'kero' and not self.direction1):
-            self.x = self.x - offset_x
+            self.x -= offset_x
         else:
-            self.x = self.x + offset_x
-        self.y = self.y + offset_y
+            self.x += offset_x
+        self.y += offset_y
         self.window.move(self.x, self.y)
         gtk.gdk.flush()
         self.left = 0
@@ -359,7 +320,7 @@ class Balloon:
         self.window.add(self.darea)
         self.darea.realize()
         self.surface_gc = self.darea.window.new_gc()
-        self.darea.window.set_back_pixmap(image, gtk.FALSE)
+        self.darea.window.set_back_pixmap(image, False)
         self.layout = None
         if text != 'noscript' and (self.right-self.left) and (self.bottom-self.top):
             self.script = text
@@ -470,11 +431,12 @@ class Balloon:
             print "-" * 50
             print e
             print script                                    
-        self.timeout_id = gtk.timeout_add(10, self.do_idle_tasks)
+        self.timeout_id = gobject.timeout_add(10, self.do_idle_tasks)
+
     def update_script(self, text, mode):
         if text:
             if mode == 2 and self.script != None:
-                self.script = self.script + text
+                self.script += text
             else:
                 self.script = text
             self.processed_script = None
@@ -489,55 +451,52 @@ class Balloon:
                 print "-" * 50
                 print e
                 print script                                    
+
     def get_sakura_status(self, id): # FIXME
         if id == 'getSurfaceSakura':
-            if self.sakura.surface.window and \
-               self.sakura.surface.window[0].shown:
+            if self.__ghost.surface_is_shown(0):
                 s0_shown = 1
             else:
                 s0_shown = 0
             try:
-                s0_x, s0_y = self.sakura.surface.get_position(0)
-                s0_w, s0_h = self.sakura.surface.get_surface_size(0)
+                s0_x, s0_y = self.__ghost.get_surface_position(0)
+                s0_w, s0_h = self.__ghost.get_surface_size(0)
             except:
                 s0_x, s0_y = 0, 0
                 s0_w, s0_h = 0, 0
             return s0_shown, s0_x, s0_y, s0_w, s0_h
         elif id == 'getSurfaceKero':
-            if self.sakura.surface.window and \
-               self.sakura.surface.window[1].shown:
+            if self.__ghost.surface_is_shown(1):
                 s1_shown = 1
             else:
                 s1_shown = 0
             try:
-                s1_x, s1_y = self.sakura.surface.get_position(1)
-                s1_w, s1_h = self.sakura.surface.get_surface_size(1)
+                s1_x, s1_y = self.__ghost.get_surface_position(1)
+                s1_w, s1_h = self.__ghost.get_surface_size(1)
             except:
                 s1_x, s1_y = 0, 0
                 s1_w, s1_h = 0, 0
             return s1_shown, s1_x, s1_y, s1_w, s1_h
         elif id == 'getBalloonSakura':
-            if self.sakura.balloon.window and \
-               self.sakura.balloon.window[0].shown:
+            if self.__ghost.balloon_is_shown(0):
                 b0_shown = 1
             else:
                 b0_shown = 0
             try:
-                b0_x, b0_y = self.sakura.balloon.get_position(0)
-                b0_w, b0_h = self.sakura.balloon.get_balloon_size(0)
+                b0_x, b0_y = self.__ghost.get_balloon_position(0)
+                b0_w, b0_h = self.__ghost.get_balloon_size(0)
             except:
                 b0_x, b0_y = 0, 0
                 b0_w, b0_h = 0, 0
             return b0_shown, b0_x, b0_y, b0_w, b0_h
         elif id == 'getBalloonKero':
-            if self.sakura.balloon.window and \
-               self.sakura.balloon.window[1].shown:
+            if self.__ghost.balloon_is_shown(1):
                 b1_shown = 1
             else:
                 b1_shown = 0
             try:
-                b1_x, b1_y = self.sakura.balloon.get_position(1)
-                b1_w, b1_h = self.sakura.balloon.get_balloon_size(1)
+                b1_x, b1_y = self.__ghost.get_balloon_position(1)
+                b1_w, b1_h = self.__ghost.get_balloon_size(1)
             except:
                 b1_x, b1_y = 0, 0
                 b1_w, b1_h = 0, 0
@@ -545,18 +504,18 @@ class Balloon:
         elif id == 'isTalking':
             talking = 0
             try:
-                if self.sakura.processed_script or \
-                   self.sakura.processed_text:
+                if self.__ghost.is_talking():
                     talking = 1
             except:
                 pass
             return talking
         elif id == 'getBottomMargin':
-            return self.sakura.bottom_margin
+            return self.__ghost.get_bottom_margin()
         elif id == 'getTopMargin':
-            return self.sakura.top_margin
+            return self.__ghost.get_top_margin()
         else:
             return None
+
     def do_idle_tasks(self):
         if not self.window:
             return None
@@ -646,14 +605,17 @@ class Balloon:
             self.talking = 0
         else:
             self.talking = sakura_talking
-        return gtk.TRUE
+        return True
+
     def redraw(self, widget, event):
         x, y, w, h = event.area
         self.darea.window.clear()
         if self.layout:
             self.darea.window.draw_layout(self.surface_gc, self.left, self.top, self.layout)
+
     def get_state(self):
         return self.state
+
     def interpret_script(self):
         if self.script_wait is not None:
             if time.time() < self.script_wait:
@@ -661,11 +623,11 @@ class Balloon:
             self.script_wait = None
         if self.processed_text:
             if self.quick_session or self.state == 'orusuban':
-                self.text = self.text + self.processed_text
+                self.text += self.processed_text
                 self.draw_text(self.text)
                 self.processed_text = ''
             else:
-                self.text = self.text + self.processed_text[0]
+                self.text += self.processed_text[0]
                 self.draw_text(self.text)
                 self.processed_text = self.processed_text[1:]
                 self.script_wait = time.time() + 0.014
@@ -674,7 +636,7 @@ class Balloon:
         if node[0] == ninix.script.SCRIPT_TAG:
             name, args = node[1], node[2:]
             if name == r'\n':
-                self.text = self.text + '\n'
+                self.text += '\n'
                 self.draw_text(self.text)
             elif name == r'\w':
                 if len(args) > 0:
@@ -706,20 +668,20 @@ class Balloon:
         elif node[0] == ninix.script.SCRIPT_TEXT:
             text = ''
             for chunk in node[1]:
-                text = text + chunk[1]
+                text += chunk[1]
             self.processed_text = text
+
     def draw_text(self, text):
-        try:
-            self.layout.set_text(text)
-        except:
-            self.layout.set_text(text, -1) # pygtk <= 1.99.14
+        self.layout.set_text(text)
         self.darea.queue_draw()
+
     def button_press(self, window, event):
         self.x_root = event.x_root
         self.y_root = event.y_root
         if event.type == gtk.gdk._2BUTTON_PRESS:
-            self.sakura.notify_event('OnEBMouseDoubleClick', self.name, int(event.x), int(event.y), self.id)
-        return gtk.TRUE
+            self.__ghost.notify_event('OnEBMouseDoubleClick', self.name, int(event.x), int(event.y), self.id)
+        return True
+
     def button_release(self, window, event):
         if self.dragged:
             self.dragged = 0
@@ -727,12 +689,13 @@ class Balloon:
         self.y_root = None
         if event.type == gtk.gdk.BUTTON_RELEASE:
             if event.button == 1:
-                self.sakura.notify_event('OnEBMouseClick', self.name, int(event.x), int(event.y), self.id, 0)
+                self.__ghost.notify_event('OnEBMouseClick', self.name, int(event.x), int(event.y), self.id, 0)
             elif event.button == 3:
-                self.sakura.notify_event('OnEBMouseClick', self.name, int(event.x), int(event.y), self.id, 1)
+                self.__ghost.notify_event('OnEBMouseClick', self.name, int(event.x), int(event.y), self.id, 1)
         if self.clickerase == 'on':
             self.destroy()
-        return gtk.TRUE
+        return True
+
     def motion_notify(self, window, event):
         if self.x_root is not None and \
            self.y_root is not None:
@@ -741,27 +704,30 @@ class Balloon:
             if event.state & gtk.gdk.BUTTON1_MASK:
                 self.dragged = 1
                 if self.dragmove_horizontal:
-                    self.x = self.x + x_delta
+                    self.x += x_delta
                 if self.dragmove_vertical:
-                    self.y = self.y + y_delta
+                    self.y += y_delta
                 self.window.move(int(self.x + self.action_x + self.vx),
                                  int(self.y + self.action_y + self.vy))
                 self.x_root = event.x_root
                 self.y_root = event.y_root
         if self.move_notify_time == None or \
            time.time() - self.move_notify_time > 500 * 0.001:
-            self.sakura.notify_event('OnEBMouseMove', self.name, int(event.x), int(event.y), self.id)
+            self.__ghost.notify_event('OnEBMouseMove', self.name, int(event.x), int(event.y), self.id)
             self.move_notify_time = time.time()
-        return gtk.TRUE
+        return True
+
     def leave_notify(self, window, event):
         self.move_notify_time = None
+
     def delete(self, window, event):
-        return gtk.TRUE
+        return True
+
     def destroy(self):
         self.visible = 0
         if self.window:
             self.window.destroy()
             self.window = None
         if self.timeout_id:
-            gtk.timeout_remove(self.timeout_id)
+            gobject.source_remove(self.timeout_id)
             self.timeout_id = None
