@@ -1,7 +1,7 @@
-# -*- coding: EUC-JP -*-
+# -*- coding: UTF-8 -*-
 #
-#  hanayu.py - a HANAYU compatible Saori module for ninix
-#  Copyright (C) 2002, 2003 by Shyouzou Sugitani <shy@debian.or.jp>
+#  hanayu.py - a "花柚" compatible Saori module for ninix
+#  Copyright (C) 2002-2005 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -11,20 +11,17 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-#  $Id: hanayu.py,v 1.18 2004/01/28 08:49:51 shy Exp $
+#  $Id: hanayu.py,v 1.27 2005/02/07 01:20:26 shy Exp $
 #
 
 # TODO:
-# - usetime, line, radar ʳηΥդؤб.
-# - ȥνĽ.(GTK+бԤ.)
+# - usetime, line, radar 以外の形式のグラフへの対応.
+# - タイトルの縦書き.(GTK+の対応待ち.)
 
 import sys
 import os
-import string
-import StringIO
 import math
 import time
-import codecs
 
 if os.environ.has_key('DISPLAY'):
     if not sys.modules.has_key('gtk'):
@@ -35,57 +32,53 @@ if os.environ.has_key('DISPLAY'):
             pass
     import gtk
     import pango
+    import ninix.pix
 else:
     gtk = None
 
-import ninix.pix
+from ninix.dll import SAORI
 
-import locale
-
-class Saori:
+class Saori(SAORI):
     __DBNAME = 'HANAYU.db'
+
     def __init__(self):
-        self.loaded = 0
+        SAORI.__init__(self)
         self.graphs = {}
         self.data = {}
-    def load(self, dir=os.curdir):
-        self.dir = dir
-        self.dbpath = os.path.join(self.dir, self.__DBNAME)
-        result = 0
+
+    def check_import(self):
         if not gtk:
-            pass
-        elif self.loaded:
-            result = 2
+            return 0
         else:
-            self.graphs = {}
-            self.data = self.read_hanayu_txt(self.dir)
-            if self.data:
-                self.loaded = 1
-                self.read_db()
-                result = 1
-        return result
+            return 1
+
+    def setup(self):
+        self.dbpath = os.path.join(self.dir, self.__DBNAME)
+        self.graphs = {}
+        self.data = self.read_hanayu_txt(self.dir)
+        if self.data:
+            self.read_db()
+            return 1
+        else:
+            return 0
+
     def read_hanayu_txt(self, dir):
         graphs = {}
         try:
             file = open(os.path.join(dir, 'hanayu.txt'), 'r')
             data = {}
             name = ''
-            while 1:
-                line = file.readline()
-                if not line:
-                    if data:
-                        graphs[name] = data
-                    break # EOF
-                line = string.strip(line)
+            for line in file:
+                line = line.strip()
                 if not line:
                     continue
                 if line[:2] == '//':
                     continue
-                comma = string.find(line, ',')
+                comma = line.find(',')
                 if line[0] == '[': # bln.txt like format
                     graphs[name] = data
                     data = {}
-                    end = string.find(line, ']')
+                    end = line.find(']')
                     if end < 0:
                         end = len(line)
                     name = line[1:end]
@@ -98,24 +91,25 @@ class Saori:
                     data = {}
                     name = ''
                 elif comma >= 0:
-                    key = string.strip(line[:comma])
-                    value = string.strip(line[comma+1:])
+                    key = line[:comma].strip()
+                    value = line[comma+1:].strip()
                     data[key] = value
                 elif not name:
                     tmp_name = line
+            if data:
+                graphs[name] = data
             return graphs
         except:
             return None
-    def unload(self):
-        if self.loaded == 0:
-            return 0
+
+    def finalize(self):
         for name in self.graphs.keys():
             self.graphs[name].destroy()
         self.graphs = {}
         self.data = {}
-        self.loaded = 0
         self.write_db()
         return 1
+
     def time_to_key(self, secs, offset):
         year = int(time.strftime("%Y", time.localtime(secs)))
         month = int(time.strftime("%m", time.localtime(secs)))
@@ -126,6 +120,7 @@ class Saori:
         day = int(time.strftime("%d", time.localtime(target_time)))
         key = str(year*10000 + month*100 + day)
         return key, year, month, day
+
     def read_db(self):
         self.seven_days = []
         current_time = self.last_update = time.time()
@@ -137,18 +132,16 @@ class Saori:
         except:
             return
         else:
-            line = file.readline()
-            line = string.strip(line)
-            if not line or line != '# Format: v1.0':
-                return
-            while 1:
-                line = file.readline()
-                if not line: # EOF
-                    break
-                line = string.strip(line)
+            ver = None
+            for line in file:
+                line = line.strip()
                 if not line:
                     continue
-                comma = string.find(line, ',')
+                if ver is None:
+                    if line == '# Format: v1.0':
+                        ver = 1
+                    continue
+                comma = line.find(',')
                 if comma < 0:
                     continue
                 key = line[:comma]
@@ -156,6 +149,7 @@ class Saori:
                     if self.seven_days[index][0] == key:
                         self.seven_days[index][4] = float(line[comma+1:])
             file.close()
+
     def update_db(self):
         current_time = time.time()
         old_seven_days = []
@@ -173,6 +167,7 @@ class Saori:
                         self.seven_days[j][4] = self.seven_days[j][4] + \
                                                 (current_time - self.last_update) / (60.0 * 60.0)
         self.last_update = current_time
+
     def write_db(self):
         self.update_db()
         try:
@@ -184,110 +179,61 @@ class Saori:
             for index in range(7):
                 file.write('%s, %s\n' % (self.seven_days[index][0], self.seven_days[index][4]))
             file.close()
-    def request(self, req):
-        type, argument = self.evaluate_request(req)
-        header = StringIO.StringIO(req)
-        line = header.readline()
-        if not type:
+
+    def execute(self, argument):
+        if len(argument) == 0:
             return 'SAORI/1.0 400 Bad Request\r\n\r\n'
-        elif type == 'GET Version':
-            return 'SAORI/1.0 204 No Content\r\n\r\n'
-        elif type == 'EXECUTE':
-            if len(argument) == 0:
-                return 'SAORI/1.0 400 Bad Request\r\n\r\n'
-            command = argument[0]
-            if command == 'show':
-                if len(argument) >= 2:
-                    name = argument[1]
-                    if self.graphs.has_key(name):
-                        self.graphs[name].destroy()
-                else:
-                    name = ''
-                if not self.data.has_key(name):
-                    return 'SAORI/1.0 400 Bad Request\r\n\r\n'
-                if self.data[name].has_key('graph') and \
-                       self.data[name]['graph'] in ['line', 'bar', 'radar', 'radar2']:
-                    type = self.data[name]['graph']
-                else:
-                    type = 'usetime'
-                if type == 'usetime':
-                    self.update_db()
-                    new_args = []
-                    for index in range(7):
-                        date = str(self.seven_days[index][2]) + \
-                               '/' + \
-                               str(self.seven_days[index][3])
-                        new_args.append(date)
-                        hours = self.seven_days[index][4]
-                        new_args.append(hours)
-                    self.graphs[name] = Line(self.dir, self.data[name], new_args, 0, 24)
-                elif type == 'line':
-                    self.graphs[name] = Line(self.dir, self.data[name], argument[2:])
-                elif type == 'bar':
-                    self.graphs[name] = Bar(self.dir, self.data[name], argument[2:])
-                elif type == 'radar':
-                    self.graphs[name] = Radar(self.dir, self.data[name], argument[2:])
-                elif type == 'radar2':
-                    self.graphs[name] = Radar2(self.dir, self.data[name], argument[2:])
-            elif command == 'hide':
-                if len(argument) >= 2:
-                    name = argument[1]
-                else:
-                    name = ''
+        command = argument[0]
+        if command == 'show':
+            if len(argument) >= 2:
+                name = argument[1]
                 if self.graphs.has_key(name):
                     self.graphs[name].destroy()
-                else:
-                    return 'SAORI/1.0 400 Bad Request\r\n\r\n'
+            else:
+                name = ''
+            if not self.data.has_key(name):
+                return 'SAORI/1.0 400 Bad Request\r\n\r\n'
+            if self.data[name].has_key('graph') and \
+                   self.data[name]['graph'] in ['line', 'bar', 'radar', 'radar2']:
+                type = self.data[name]['graph']
+            else:
+                type = 'usetime'
+            if type == 'usetime':
+                self.update_db()
+                new_args = []
+                for index in range(7):
+                    date = str(self.seven_days[index][2]) + \
+                           '/' + \
+                           str(self.seven_days[index][3])
+                    new_args.append(date)
+                    hours = self.seven_days[index][4]
+                    new_args.append(hours)
+                self.graphs[name] = Line(self.dir, self.data[name], new_args, 0, 24)
+            elif type == 'line':
+                self.graphs[name] = Line(self.dir, self.data[name], argument[2:])
+            elif type == 'bar':
+                self.graphs[name] = Bar(self.dir, self.data[name], argument[2:])
+            elif type == 'radar':
+                self.graphs[name] = Radar(self.dir, self.data[name], argument[2:])
+            elif type == 'radar2':
+                self.graphs[name] = Radar2(self.dir, self.data[name], argument[2:])
+        elif command == 'hide':
+            if len(argument) >= 2:
+                name = argument[1]
+            else:
+                name = ''
+            if self.graphs.has_key(name):
+                self.graphs[name].destroy()
             else:
                 return 'SAORI/1.0 400 Bad Request\r\n\r\n'
-            return 'SAORI/1.0 204 No Content\r\n\r\n'
-    def evaluate_request(self, req):
-        type = None
-        argument = []
-        charset = 'Shift_JIS' # default
-        header = StringIO.StringIO(req)
-        line = header.readline()
-        if not line:
-            return type, argument
-        if line[-1] == '\n':
-            line = line[:-1]
-        line = string.strip(line)
-        if not line:
-            return type, argument
-        for request in ['EXECUTE', 'GET Version']:
-            if line[:len(request)] == request:
-                type = request
-                break
-        while 1:
-            line = header.readline()
-            if not line:
-                break # EOF
-            if line[-1] == '\n':
-                line = line[:-1]
-            line = string.strip(line)
-            if not line:
-                continue
-            colon = string.find(line, ':')
-            if colon >= 0:
-                key = string.strip(line[:colon])
-                value = string.strip(line[colon+1:])
-                if key == 'Charset':
-                    charset = value
-                    try:
-                        codecs.lookup(charset)
-                    except:
-                        sys.stderr.write("Unsupported charset %s" % repr(charset))
-                if key[:8] == 'Argument': ## FIXME
-                    argument.append(value)
-                else:
-                    continue
-        for i in range(len(argument)):
-            argument[i] = unicode(argument[i], charset, 'ignore')
-        return type, argument
+        else:
+            return 'SAORI/1.0 400 Bad Request\r\n\r\n'
+        return 'SAORI/1.0 204 No Content\r\n\r\n'
 
 class Graph:
     width = 450
     height = 340
+
     def __init__(self, dir, data, args=[], min=None, max=None):
         self.dir = dir
         self.data = data
@@ -299,11 +245,12 @@ class Graph:
         self.draw_frame()
         self.draw_graph()
         self.window.show()
+
     def create_window(self):
         self.window = gtk.Window()
-        self.window.set_title(unicode('ͮ', 'EUC-JP').encode(locale.nl_langinfo(locale.CODESET)))
-        self.window.set_decorated(gtk.FALSE)
-        self.window.set_resizable(gtk.FALSE)
+        self.window.set_title('花柚') # UTF-8
+        self.window.set_decorated(False)
+        self.window.set_resizable(False)
         self.window.connect("delete_event", self.delete)
         self.window.connect("button_press_event", self.button_press)
         self.window.set_events(gtk.gdk.BUTTON_PRESS_MASK)
@@ -321,15 +268,17 @@ class Graph:
         pixbuf = None
         if self.data.has_key('background.filename'):
             path = os.path.join(self.dir,
-                                string.replace(self.data['background.filename'],
-                                               '\\', '/'))
+                                self.data['background.filename'].replace('\\', '/'))
             
-            pixbuf = ninix.pix.create_pixbuf_from_file(path, 'png')
+            try:
+                pixbuf = ninix.pix.create_pixbuf_from_file(path, 'png')
+            except:
+                pixbuf = None
         self.surface_pixmap = gtk.gdk.Pixmap(None, self.width, self.height, gtk.gdk.visual_get_best_depth())
         cmap = self.darea.get_colormap()
         self.surface_gc = self.surface_pixmap.new_gc()
         self.surface_gc.foreground = cmap.alloc_color("#FFFFFF")
-        self.surface_pixmap.draw_rectangle(self.surface_gc, gtk.TRUE, 0, 0,
+        self.surface_pixmap.draw_rectangle(self.surface_gc, True, 0, 0,
                                            self.width, self.height)
         if pixbuf:
             width = pixbuf.get_width()
@@ -341,6 +290,7 @@ class Graph:
                                       gtk.gdk.RGB_DITHER_NONE, 0, 0)
         self.darea.window.draw_drawable(self.surface_gc, self.surface_pixmap,
                                         0, 0, 0, 0, self.width, self.height)
+
     def draw_title(self):
         fontcolor_r = fontcolor_g = fontcolor_b = 0
         if self.data.has_key('font.color'):
@@ -367,34 +317,37 @@ class Graph:
         i = 0
         while i < len(self.title):
             if text:
-                text = text + '\n'
-            text = text + self.title[i]
-            i = i + 1
+                text += '\n'
+            text += self.title[i]
+            i += 1
         self.layout.set_font_description(self.font_desc)
         self.layout.set_wrap(pango.WRAP_CHAR)
         self.layout.set_alignment(pango.ALIGN_CENTER)
-        try:
-            self.layout.set_text(text)
-        except:
-            self.layout.set_text(text, -1) # pygtk <= 1.99.14
+        self.layout.set_text(text)
         self.surface_pixmap.draw_layout(self.surface_gc, 20, 58, self.layout)
+
     def draw_frame(self):
         pass
+
     def draw_graph(self):
         pass
+
     def redraw(self, widget, event):
         x, y, w, h = event.area
         if self.surface_pixmap:
             self.darea.window.draw_drawable(self.surface_gc, self.surface_pixmap,
                                             x, y, x, y, w, h)
+
     def button_press(self, window, event):
         if event.type == gtk.gdk.BUTTON_PRESS:
             self.window.begin_move_drag(event.button, int(event.x_root), int(event.y_root), gtk.get_current_event_time())
         elif event.type == gtk.gdk._2BUTTON_PRESS: # double click
             self.destroy()
-        return gtk.TRUE
+        return True
+
     def delete(self, window, event):
-        return gtk.TRUE
+        return True
+
     def destroy(self):
         if self.window:
             self.window.destroy()
@@ -402,6 +355,7 @@ class Graph:
             self.timeout_id = None
 
 class Line(Graph):
+
     def draw_frame(self):
         framecolor_r = framecolor_g = framecolor_b = 0
         if self.data.has_key('frame.color'):
@@ -426,14 +380,12 @@ class Line(Graph):
                                       60, 48, 60, 260)
         self.surface_pixmap.draw_line(self.surface_gc,
                                       60, 260, 420, 260)
+
     def draw_graph(self):
         num = len(self.args)/2
         step = 368 / num 
         for index in range(num):
-            try:
-                self.layout.set_text(self.args[index*2])
-            except:
-                self.layout.set_text(self.args[index*2], -1) # pygtk <= 1.99.14
+            self.layout.set_text(self.args[index*2])
             w, h = self.layout.get_pixel_size()
             pos_x = 60 + index*step + step/2 - w/2
             pos_y = 268
@@ -482,22 +434,28 @@ class Line(Graph):
             image, mask = None, None
             if self.args[index*2+1] == min and self.data.has_key('mark0.filename'):
                 path = os.path.join(self.dir,
-                                    string.replace(self.data['mark0.filename'],
-                                                   '\\', '/'))
+                                    self.data['mark0.filename'].replace('\\', '/'))
                 if os.path.exists(path):
-                    image, mask = ninix.pix.create_pixmap_from_file(path)
+                    try:
+                        image, mask = ninix.pix.create_pixmap_from_file(path)
+                    except:
+                        image, mask = None, None
             elif self.args[index*2+1] == max and self.data.has_key('mark2.filename'):
                 path = os.path.join(self.dir,
-                                    string.replace(self.data['mark2.filename'],
-                                                   '\\', '/'))
+                                    self.data['mark2.filename'].replace('\\', '/'))
                 if os.path.exists(path):
-                    image, mask = ninix.pix.create_pixmap_from_file(path)
+                    try:
+                        image, mask = ninix.pix.create_pixmap_from_file(path)
+                    except:
+                        image, mask = None, None
             elif self.data.has_key('mark1.filename'):
                 path = os.path.join(self.dir,
-                                    string.replace(self.data['mark1.filename'],
-                                                   '\\', '/'))
+                                    self.data['mark1.filename'].replace('\\', '/'))
                 if os.path.exists(path):
-                    image, mask = ninix.pix.create_pixmap_from_file(path)
+                    try:
+                        image, mask = ninix.pix.create_pixmap_from_file(path)
+                    except:
+                        image, mask = None, None
             if image:
                 w, h = image.get_size()
                 x = 60 + index*step + step/2 - w/2
@@ -508,6 +466,7 @@ class Line(Graph):
                 self.surface_pixmap.draw_drawable(gc, image, 0, 0, x, y, w, h)
 
 class Bar(Graph):
+
     def draw_graph(self):
         barcolor_r = barcolor_g = barcolor_b = 0
         if self.data.has_key('bar.color'):
@@ -531,8 +490,10 @@ class Bar(Graph):
 class Radar(Graph):
     width = 288
     height = 288
+
     def __init__(self, dir, data, args=[]):
         Graph.__init__(self, dir, data, args)
+
     def draw_frame(self):
         framecolor_r = framecolor_g = framecolor_b = 0
         if self.data.has_key('frame.color'):
@@ -559,6 +520,7 @@ class Radar(Graph):
             y = 146 - int(math.sin(math.pi*(0.5-2.0*index/num))*114)
             self.surface_pixmap.draw_line(self.surface_gc,
                                           146, 146, x, y)
+
     def draw_graph(self):
         num = len(self.args)/2
         for index in range(num):
@@ -637,15 +599,13 @@ class Radar(Graph):
                 value = 1.0
             x = 146 + int(math.cos(math.pi*(0.5-2.0*index/num))*value*100)
             y = 146 - int(math.sin(math.pi*(0.5-2.0*index/num))*value*100)
-            try:
-                self.layout.set_text(self.args[index*2])
-            except:
-                self.layout.set_text(self.args[index*2], -1) # pygtk <= 1.99.14
+            self.layout.set_text(self.args[index*2])
             self.surface_pixmap.draw_layout(self.surface_gc, x, y + 12, self.layout)
 
 class Radar2(Graph):
     width = 288
     height = 288
+
     def __init__(self, dir, data, args=[]):
         Graph.__init__(self, dir, data, args)
 
