@@ -1,9 +1,22 @@
-# -*- coding: EUC-JP -*-
-# Tamito KAJIYAMA <14 July 2001>
-# $Id: niseshiori.py,v 1.12 2003/12/05 04:37:16 shy Exp $
-# NOTE: This file contains Japanese characters (EUC-JP).
+# -*- coding: UTF-8 -*-
+#
+#  niseshiori.py - a "偽栞" compatible Shiori module for ninix
+#  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
+#  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
+#  Copyright (C) 2002-2004 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2003 by Shun-ichi TAHARA <jado@flowernet.gr.jp>
+#
+#  This program is free software; you can redistribute it and/or modify it
+#  under the terms of the GNU General Public License (version 2) as
+#  published by the Free Software Foundation.  It is distributed in the
+#  hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
+#  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+#  PURPOSE.  See the GNU General Public License for more details.
+#
+# $Id: niseshiori.py,v 1.20 2004/06/23 05:57:04 shy Exp $
+#
 
-import whrandom
+import random
 import time
 import sys
 import os
@@ -13,19 +26,16 @@ import StringIO
 from types import *
 
 import codecs
-import locale
 
 try:
     import _niseshiori
 except ImportError:
     _niseshiori = None
 
-REVISION = "$Revision: 1.12 $"
+REVISION = "$Revision: 1.20 $"
 
 builtin_open = open
 
-locale_charset = locale.nl_langinfo(locale.CODESET)
-
 def list_dict(dir):
     buffer = []
     try:
@@ -84,7 +94,7 @@ class NiseShiori:
         except IOError:
             return
         dict = {}
-        for line in file.readlines():
+        for line in file:
             if line[:9] == "# ns_st: ":
                 try:
                     self.ai_talk_interval = int(line[9:])
@@ -92,10 +102,10 @@ class NiseShiori:
                     pass
                 continue
             elif line[:9] == "# ns_tn: ":
-                self.username = string.strip(line[9:])
+                self.username = line[9:].strip()
                 continue
             try:
-                name, value = map(string.strip, string.split(line, "="))
+                name, value = [s.strip() for s in line.split("=")]
             except ValueError:
                 print "niseshiori.py: malformed database (ignored)"
                 return
@@ -134,12 +144,12 @@ class NiseShiori:
         in_comment = 0
         i, j = 0, len(buffer)
         while i < j:
-            line = string.strip(buffer[i])
-            i = i + 1
+            line = buffer[i].strip()
+            i += 1
             if not line:
                 continue
             elif i == 1 and line[:9] == "#Charset:":
-                charset = string.strip(line[9:])
+                charset = line[9:].strip()
                 if charset == "UTF-8":
                     decode = lambda line: unicode(line, 'utf-8')
                 elif charset in ["EUC-JP", "EUC-KR"]:
@@ -155,8 +165,8 @@ class NiseShiori:
                 continue
             lines = [line]
             while i < j and buffer[i] and buffer[i][0] in [" ", "\t"]:
-                lines.append(string.strip(buffer[i]))
-                i = i + 1
+                lines.append(buffer[i].strip())
+                i += 1
             definitions.append(string.join(lines, ''))
         # parse each line
         for line in definitions:
@@ -164,13 +174,13 @@ class NiseShiori:
             # special case: words in a category
             match = self.re_category.match(line)
             if match:
-                line = string.strip(line[match.end():])
+                line = line[match.end():].strip()
                 if not line or line[0] != ",":
                     self.syntax_error(path, line)
                     continue
-                words = filter(None, map(string.strip, self.split(line)))
+                words = [s.strip() for s in self.split(line) if s.strip()]
                 type, catlist = match.groups()
-                for cat in map(string.strip, self.split(catlist)):
+                for cat in [s.strip() for s in self.split(catlist)]:
                     if type is None:
                         keylist = [(None, cat)]
                     else:
@@ -187,12 +197,12 @@ class NiseShiori:
                 continue
             # other cases
             try:
-                command, argv = map(string.strip, self.split(line, 1))
+                command, argv = [s.strip() for s in self.split(line, 1)]
             except ValueError:
                 self.syntax_error(path, line)
                 continue
             if command == r"\ch":
-                argv = map(string.strip, self.split(argv))
+                argv = [s.strip() for s in self.split(argv)]
                 if len(argv) == 5:
                     t1, w1, t2, w2, c = argv
                 elif len(argv) == 4:
@@ -245,7 +255,7 @@ class NiseShiori:
                     list.append(w2)
                     self.dict[t2] = list
             elif self.re_type.match(command) or self.re_user.match(command):
-                words = filter(None, map(string.strip, self.split(argv)))
+                words = [s.strip() for s in self.split(argv) if s.strip()]
                 value = self.dict.get(command, [])
                 value.extend(words)
                 self.dict[command] = value
@@ -254,7 +264,7 @@ class NiseShiori:
                 value.append(argv)
                 self.dict[command] = value
             elif command == r"\ft":
-                argv = map(string.strip, self.split(argv, 2))
+                argv = [s.strip() for s in self.split(argv, 2)]
                 if len(argv) != 3:
                     self.syntax_error(path, line)
                     continue
@@ -264,35 +274,35 @@ class NiseShiori:
                     continue
                 self.keywords[(w, t)] = s
             elif command == r"\re":
-                argv = map(string.strip, self.split(argv, 1))
+                argv = [s.strip() for s in self.split(argv, 1)]
                 if len(argv) == 2:
                     cond = self.parse_condition(argv[0])
                     list = self.responses.get(cond, [])
                     list.append(argv[1])
                     self.responses[cond] = list
             elif command == r"\hl":
-                argv = map(string.strip, self.split(argv, 1))
+                argv = [s.strip() for s in self.split(argv, 1)]
                 if len(argv) == 2:
                     list = self.greetings.get(argv[0], [])
                     list.append(argv[1])
                     self.greetings[argv[0]] = list
             elif command == r"\ev":
-                argv = map(string.strip, self.split(argv, 1))
+                argv = [s.strip() for s in self.split(argv, 1)]
                 if len(argv) == 2:
                     cond = self.parse_condition(argv[0])
                     list = self.events.get(cond, [])
                     list.append(argv[1])
                     self.events[cond] = list
             elif command == r"\id":
-                argv = map(string.strip, self.split(argv, 1))
+                argv = [s.strip() for s in self.split(argv, 1)]
                 if len(argv) == 2:
                     if argv[0] in ["sakura.recommendsites",
                                    "kero.recommendsites",
                                    "sakura.portalsites"]:
                         list = self.resources.get(argv[0], "")
 	                if list:
-                            list = list + '\2'
-	                list = list + string.replace(argv[1], ' ', '\1')
+                            list += '\2'
+	                list += argv[1].replace(' ', '\1')
                         self.resources[argv[0]] = list
                     else:
                         self.resources[argv[0]] = argv[1]
@@ -305,17 +315,17 @@ class NiseShiori:
         count = 0
         end = pos = 0
         while maxcount is None or count < maxcount:
-            pos = string.find(line, ",", pos)
+            pos = line.find(",", pos)
             if pos < 0:
                 break
             elif pos > 0 and line[pos-1] == "\\":
-                pos = pos + 1
+                pos += 1
             else:
                 buffer.append(line[end:pos])
-                count = count + 1
+                count += 1
                 end = pos = pos + 1
         buffer.append(line[end:])
-        return map(lambda s:  string.replace(s, "\\,", ","), buffer)
+        return [s.replace("\\,", ",") for s in  buffer]
     def syntax_error(self, path, line):
         if self.debug & 4:
             print "niseshiori.py: syntax error in", os.path.basename(path)
@@ -325,13 +335,13 @@ class NiseShiori:
     COND_STRING     = 2
     def parse_condition(self, condition):
         buffer = []
-        for expr in map(string.strip, string.split(condition, "&")):
+        for expr in [s.strip() for s in condition.split("&")]:
             match = self.re_comp_op.search(expr)
             if match:
                 buffer.append((self.COND_COMPARISON, (
-                    string.strip(expr[:match.start()]),
+                    expr[:match.start()].strip(),
                     match.group(),
-                    string.strip(expr[match.end():]))))
+                    expr[match.end():].strip())))
             else:
                 buffer.append((self.COND_STRING, expr))
         return tuple(buffer)
@@ -345,18 +355,18 @@ class NiseShiori:
         line = []
         while i < j:
             if data[i] == "@":
-                i = i + 1
+                i += 1
                 buffer.append(string.join(line, ''))
                 line = []
                 continue
             y = ord(data[i])
-            i = i + 1
+            i += 1
             x = ord(data[i])
-            i = i + 1
-            x = x - a
-            a = a + 9
-            y = y - a
-            a = a + 2
+            i += 1
+            x -= a
+            a += 9
+            y -= a
+            a += 2
             if a > 0xdd:
                 a = 0x61
             line.append(chr((x & 0x03) | ((y & 0x03) << 2) | ((y & 0x0c) << 2) | ((x & 0x0c) << 4)))
@@ -394,18 +404,18 @@ class NiseShiori:
             if ref != None and type(ref) not in [IntType, FloatType]:
                 ref = unicode(ref, 'utf-8', 'ignore')
             return ref
-        [ref0, ref1, ref2, ref3, ref4, ref5, ref6, ref7] = map(proc, [ref0, ref1, ref2, ref3, ref4, ref5, ref6, ref7])
+        ref = [proc(ref) for ref in [ref0, ref1, ref2, ref3, ref4, ref5, ref6, ref7]]
         if event in ["OnSecondChange", "OnMinuteChange"]:
-            if ref1:
-                self.mikire = self.mikire + 1
+            if ref[1]:
+                self.mikire += 1
                 script = self.get_event_response("OnNSMikireHappen")
                 if script is not None:
                     return script
             elif self.mikire > 0:
                 self.mikire = 0
                 return self.get_event_response("OnNSMikireSolve")
-            if ref2:
-                self.kasanari = self.kasanari + 1
+            if ref[2]:
+                self.kasanari += 1
                 script = self.get_event_response("OnNSKasanariHappen")
                 if script is not None:
                     return script
@@ -413,20 +423,20 @@ class NiseShiori:
                 self.kasanari = 0
                 return self.get_event_response("OnNSKasanariHappen")
             if event == "OnSecondChange" and self.ai_talk_interval > 0:
-                self.ai_talk_count = self.ai_talk_count + 1
+                self.ai_talk_count += 1
                 if self.ai_talk_count == self.ai_talk_interval:
                     self.ai_talk_count = 0
                     if len(self.otherghost) > 0 and \
-                       whrandom.randint(0, 10) == 0:
+                       random.randint(0, 10) == 0:
                         target = []
                         for name, s0, s1 in self.otherghost:
                             if self.greetings.has_key(name):
                                 target.append(name)
                         if len(target) > 0:
-                            self.to = whrandom.choice(target)
+                            self.to = random.choice(target)
                         if self.to:
                             self.current_time = time.localtime(time.time())
-                            s = whrandom.choice(self.greetings[self.to])
+                            s = random.choice(self.greetings[self.to])
                             if s:
                                 s = self.replace_meta(s)
                                 while 1:
@@ -439,36 +449,36 @@ class NiseShiori:
                     return self.getaistringrandom()
             return None
         elif event == "OnMouseMove":
-            if self.motion_area != (ref3, ref4):
-                self.motion_area = (ref3, ref4)
+            if self.motion_area != (ref[3], ref[4]):
+                self.motion_area = (ref[3], ref[4])
                 self.motion_count = 0
             else:
-                self.motion_count = self.motion_count + 5 # sensitivity
+                self.motion_count += 5 # sensitivity
         elif event == "OnSurfaceChange":
-            self.surf0 = ref0
-            self.surf1 = ref1
-        elif event == "OnUserInput" and ref0 == "ninix.niseshiori.username":
-            self.username = ref1
+            self.surf0 = ref[0]
+            self.surf1 = ref[1]
+        elif event == "OnUserInput" and ref[0] == "ninix.niseshiori.username":
+            self.username = ref[1]
             self.save_database()
             return "\e"
         elif event == "OnCommunicate":
             self.event = ''
-            self.reference = (ref1, )
-            if ref0 == 'user':
+            self.reference = (ref[1], )
+            if ref[0] == 'user':
                 self.sender = 'User'
             else:
-                self.sender = ref0
+                self.sender = ref[0]
             candidate = []
             for cond in self.responses.keys():
                 if self.eval_condition(cond):
                     candidate.append(cond)
             script = None
-            self.to = ref0
+            self.to = ref[0]
             if len(candidate) > 0:
-                cond = whrandom.choice(candidate)
-                script = whrandom.choice(self.responses[cond])
+                cond = random.choice(candidate)
+                script = random.choice(self.responses[cond])
             if not script and self.responses.has_key("nohit"):
-                script = whrandom.choice(self.responses["nohit"])
+                script = random.choice(self.responses["nohit"])
             if not script:
                 self.to = ''
             else:
@@ -484,7 +494,7 @@ class NiseShiori:
         key = "action"
         self.dict[key] = []
         self.event = event
-        self.reference = (ref0, ref1, ref2, ref3, ref4, ref5, ref6, ref7)
+        self.reference = tuple(ref)
         self.current_time = time.localtime(time.time())
         for condition, actions in self.events.items():
             if self.eval_condition(condition):
@@ -500,7 +510,7 @@ class NiseShiori:
     def otherghostname(self, list):
         self.otherghost = []
         for ghost in list:
-            name, s0, s1 = string.split(ghost, chr(1))
+            name, s0, s1 = ghost.split(chr(1))
             self.otherghost.append([unicode(name, 'utf-8', 'ignore'), s0, s1])
         return ''
     def communicate_to(self):
@@ -535,10 +545,10 @@ class NiseShiori:
             elif expr[1] == "<>":
                 return op1 != op2
         elif type == NiseShiori.COND_STRING:
-            if string.find(self.event, expr) >= 0:
+            if self.event.find(expr) >= 0:
                 return 1
             for ref in self.reference:
-                if ref is not None and string.find(str(ref), expr) >= 0:
+                if ref is not None and str(ref).find(expr) >= 0:
                     return 1
             return 0
 
@@ -562,7 +572,7 @@ class NiseShiori:
             self.to = ''
         elif tag == r"\ns_hl":
             if len(self.otherghost) > 0:
-                self.to = whrandom.choice(self.otherghost)[0]
+                self.to = random.choice(self.otherghost)[0]
         elif tag[:7] == r"\ns_st[" and tag[-1:] == "]":
             try:
                 num = int(tag[7:-1])
@@ -588,10 +598,10 @@ class NiseShiori:
             self.jump_entry = None
         elif tag[:5] == r"\set[" and tag[-1:] == "]":
             statement = tag[5:-1]
-            pos = string.find(statement, "=")
+            pos = statement.find("=")
             if pos > 0:
-                name = string.strip(statement[:pos])
-                expr = string.strip(statement[pos+1:])
+                name = statement[:pos].strip()
+                expr = statement[pos+1:].strip()
                 value = self.eval_expression(expr)
                 if value is not None:
                     self.variables[name] = value
@@ -633,10 +643,10 @@ class NiseShiori:
                         if chains.has_key(chained_meta):
                             candidates_A, candidates_B = chains[chained_meta]
                             if candidates_A:
-                                word = whrandom.choice(candidates_A)
+                                word = random.choice(candidates_A)
                                 candidates_A.remove(word)
                             else:
-                                word = whrandom.choice(candidates_B)
+                                word = random.choice(candidates_B)
                                 candidates_B.remove(word)
                             if not candidates_A and not candidates_B:
                                 del chains[chained_meta]
@@ -645,7 +655,7 @@ class NiseShiori:
                             break
                     else:
                         if match.group(4) == 'm?':
-                            word = self.expand("\\" + whrandom.choice(["ms", "mz", "ml", "mc", "mh", "mt", "me", "mp"]), s)
+                            word = self.expand("\\" + random.choice(["ms", "mz", "ml", "mc", "mh", "mt", "me", "mp"]), s)
                         else:
                             word = self.expand("\\" + match.group(4), s)
                     chains = self.find_chains((chained_meta, word), s)
@@ -670,7 +680,7 @@ class NiseShiori:
     def expand(self, key, context, default=""):
         choices = []
         for keyword, word in self.type_chains.get(key, []):
-            if not string.find(context, keyword) < 0:
+            if not context.find(keyword) < 0:
                 if self.debug & 16:
                     print "chain keyword:", keyword
                 choices.append(word)
@@ -685,14 +695,14 @@ class NiseShiori:
                     key = "(%s, %s)" % key
                 sys.stderr.write("%s not found\n" % key)
             return default
-        s = whrandom.choice(choices)
+        s = random.choice(choices)
         t = self.replace_meta(s)
         if self.debug & 16:
             if type(key) == type(()):
                 key = "\\%s[%s]" % (key[0] or "", key[1])
-            print key.encode(locale_charset, 'ignore'), "=>", s.encode(locale_charset, 'ignore')
+            print key.encode('UTF-8', 'ignore'), "=>", s.encode('UTF-8', 'ignore')
             print " " * len(key),
-            print "=>", t.encode(locale_charset, 'ignore')
+            print "=>", t.encode('UTF-8', 'ignore')
         return t
     def find_chains(self, key, context):
         chains = {}
@@ -701,7 +711,7 @@ class NiseShiori:
             candidates_A = []
             candidates_B = []
             for keyword, chained_word in dict[chained_meta]:
-                if keyword and not string.find(context, keyword) < 0:
+                if keyword and not context.find(keyword) < 0:
                     candidates_A.append(chained_word)
                 else:
                     candidates_B.append(chained_word)
@@ -723,10 +733,10 @@ class NiseShiori:
                 return value
         elif name[:6] == "%rand[" and name[-1] == "]":
             n = int(name[6:-1])
-            return whrandom.randint(1, n)
+            return random.randint(1, n)
         elif name[:5] == "%rand" and len(name) == 6:
             n = int(name[5])
-            return whrandom.randint(10**(n-1), 10**n-1)
+            return random.randint(10**(n-1), 10**n-1)
         elif name[:4] == "%ref" and len(name) == 5 and name[4] in "01234567":
             if self.reference is None:
                 return ""
@@ -768,9 +778,9 @@ class NiseShiori:
             return str(self.kasanari)
         elif name == "%ver":
             if REVISION[1:11] == "Revision: ":
-                return " for ninix (rev.%s)" % REVISION[11:-2]
+                return "偽栞 for ninix (rev.%s)" % REVISION[11:-2]
             else:
-                return " for ninix"
+                return "偽栞 for ninix"
         elif name == "%sender":
             if self.sender:
                 return self.sender
@@ -780,7 +790,7 @@ class NiseShiori:
             if self.to:
                 return self.to
             elif len(self.otherghost) > 0:
-                return whrandom.choice(self.otherghost)[0]
+                return random.choice(self.otherghost)[0]
             else:
                 return ''
         return "\\" + name
@@ -862,14 +872,14 @@ class ExprParser:
                 continue
             match = self.re_token.match(data, end)
             if match:
-                if string.strip(match.group()):
+                if match.group().strip():
                     buffer.append(match.group())
                 end = match.end()
                 continue
             match = self.re_token.search(data, end)
             if match:
                 buffer.append(data[end:match.start()])
-                if string.strip(match.group()):
+                if match.group().strip():
                     buffer.append(match.group())
                 end = match.end()
             else:
@@ -980,28 +990,31 @@ class Shiori(NiseShiori):
         return result
     def show_description(self):
         sys.stdout.write('Shiori: NiseShiori compatible module for ninix\n'
-                         '        Copyright (c) 2001, 2002 by Tamito KAJIYAMA\n')
+                         '        Copyright (C) 2001, 2002 by Tamito KAJIYAMA\n'
+                         '        Copyright (C) 2002, 2003 by MATSUMURA Namihiko\n'
+                         '        Copyright (C) 2002-2004 by Shyouzou Sugitani\n'
+                         '        Copyright (C) 2003 by Shun-ichi TAHARA\n')
     def request(self, req_string):
         header = StringIO.StringIO(req_string)
         req_header = {}
         line = header.readline()
         if line:
-            line = string.strip(line)
-            list = string.split(line)
+            line = line.strip()
+            list = line.split()
             if len(list) >= 2:
-                command = string.strip(list[0])
-                protocol = string.strip(list[1])
+                command = list[0].strip()
+                protocol = list[1].strip()
             while 1:
                 line = header.readline()
                 if not line:
                     break # EOF
-                line = string.strip(line)
+                line = line.strip()
                 if not line:
                     continue
-                colon = string.find(line, ':')
+                colon = line.find(':')
                 if colon >= 0:
-                    key = string.strip(line[:colon])
-                    value = string.strip(line[colon+1:])
+                    key = line[:colon].strip()
+                    value = line[colon+1:].strip()
                     try:
                         value = int(value)
                     except:
@@ -1022,7 +1035,7 @@ class Shiori(NiseShiori):
                                       "mt", "me", "mp"]:
                 result = self.getword(req_header['ID'])
             elif req_header['ID'] == "m?":
-                result = self.getword(whrandom.choice(["ms", "mz", "ml", "mc", "mh","mt", "me", "mp"]))
+                result = self.getword(random.choice(["ms", "mz", "ml", "mc", "mh","mt", "me", "mp"]))
             elif req_header['ID'] == 'otherghostname':
                 otherghost = []
                 for n in range(128):
@@ -1052,7 +1065,7 @@ class Shiori(NiseShiori):
                  'Value: %s\r\n' % result
         if to != None:
             result = result + 'Reference0: %s\r\n' % to
-        result = result + '\r\n'
+        result += '\r\n'
         return result
 
 def open(shiori_dir, debug=0):
@@ -1082,26 +1095,26 @@ def dump_dict(ns):
     for k, v in ns.dict.items():
         if type(k) == type(()):
             k = "(%s, %s)" % k
-        print k.encode(locale_charset, 'ignore') ## FIXME
-        for e in v: print "\t", e.encode(locale_charset, 'ignore') ## FIXME
+        print k.encode('UTF-8', 'ignore')
+        for e in v: print "\t", e.encode('UTF-8', 'ignore')
     print "*" * 50
     print "CHAINS"
     for t, list in ns.type_chains.items():
-        print t.encode(locale_charset, 'ignore') ## FIXME
+        print t.encode('UTF-8', 'ignore')
         for c, w in list:
-            print ("-> %s, %s" % (c, w)).encode(locale_charset, 'ignore') ## FIXME
+            print ("-> %s, %s" % (c, w)).encode('UTF_8', 'ignore')
     for key, dict in ns.word_chains.items():
-        print ("(%s, %s)" % key).encode(locale_charset, 'ignore') ## FIXME
+        print ("(%s, %s)" % key).encode('UTF-8', 'ignore')
         for t, list in dict.items():
-            prefix = "-> %s" % t.encode(locale_charset, 'ignore') ## FIXME
+            prefix = "-> %s" % t.encode('UTF-8', 'ignore')
             for c, w in list:
-                print prefix, ("-> %s, %s" % (c, w)).encode(locale_charset, 'ignore') ## FIXME
+                print prefix, ("-> %s, %s" % (c, w)).encode('UTF-8', 'ignore')
                 prefix = "   " + " " * len(t)
     print "*" * 50
     print "KEYWORDS"
     for (t, w), s in ns.keywords.items():
-        print t.encode(locale_charset, 'ignore'), w.encode(locale_charset, 'ignore') ## FIXME
-        print "->", s.encode(locale_charset, 'ignore') ## FIXME
+        print t.encode('UTF-8', 'ignore'), w.encode('UTF-8', 'ignore')
+        print "->", s.encode('UTF-8', 'ignore')
     print "*" * 50
     print "RESPONSES"
     for k, v in ns.responses.items():
@@ -1110,22 +1123,22 @@ def dump_dict(ns):
     print "*" * 50
     print "GREETINGS"
     for k, v in ns.greetings.items():
-        print k.encode(locale_charset, 'ignore')
+        print k.encode('UTF-8', 'ignore')
         print "->", v
     print "*" * 50
     print "EVENTS"
     for k, v in ns.events.items():
         print_condition(k)
         for e in v:
-            print "->", e.encode(locale_charset, 'ignore')
+            print "->", e.encode('UTF-8', 'ignore')
     
 def print_condition(condition):
     prefix = "Condition"
     for type, expr in condition:
         if type == NiseShiori.COND_COMPARISON:
-            print prefix, ("'%s' '%s' '%s'" % expr).encode(locale_charset, 'ignore') ## FIXME
+            print prefix, ("'%s' '%s' '%s'" % expr).encode('UTF-8', 'ignore')
         elif type == NiseShiori.COND_STRING:
-            print prefix, "'%s'" % expr.encode(locale_charset, 'ignore') ## FIXME
+            print prefix, "'%s'" % expr.encode('UTF-8', 'ignore')
         prefix = "      and"
 
 if __name__ == "__main__":
