@@ -1,6 +1,20 @@
 # -*- coding: EUC-JP -*-
-# Tamito KAJIYAMA <21 April 2002>
-# $Id: satori.py,v 1.41 2004/01/30 04:59:21 shy Exp $
+#
+#  satori.py - a "Τ" compatible Shiori module for ninix
+#  Copyright (C) 2002 by Tamito KAJIYAMA
+#  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
+#  Copyright (C) 2002-2004 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2003, 2004 by Shun-ichi TAHARA <jado@flowernet.gr.jp>
+#
+#  This program is free software; you can redistribute it and/or modify it
+#  under the terms of the GNU General Public License (version 2) as
+#  published by the Free Software Foundation.  It is distributed in the
+#  hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
+#  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+#  PURPOSE.  See the GNU General Public License for more details.
+#
+# $Id: satori.py,v 1.54 2004/10/06 02:58:21 shy Exp $
+#
 
 # TODO:
 # - եס ü쵭̵, replace̵ʤ
@@ -18,11 +32,9 @@ import string
 import sys
 import re
 import time
-import whrandom
+import random
 import StringIO
 
-import kanjilib
-
 builtin_open = open
 
 NODE_TEXT       = 1
@@ -89,10 +101,10 @@ class Filter:
         while i < j:
             if text[i] < "\x80":
                 buffer.append(text[i])
-                i = i + 1
+                i += 1
             else:
                 buffer.append(text[i:i+2])
-                i = i + 2
+                i += 2
         return buffer
     # an implementation of the Boyer-Moore text searching algorithm
     def _find(self, text, pat, start=None, end=None):
@@ -118,11 +130,11 @@ class Filter:
             i = k
             j = m - 1
             while j >= 0 and text[i] == pat[j]:
-                i = i - 1
-                j = j - 1
+                i -= 1
+                j -= 1
             if j == -1:
                 return i + 1
-            k = k + skip.get(text[k], m)
+            k += skip.get(text[k], m)
         return -1
     def _replace(self, text, pat, rep):
         start = 0
@@ -131,7 +143,7 @@ class Filter:
             if pos < 0:
                 break
             text[pos:pos+len(pat)] = rep
-            start = pos+len(rep)
+            start = pos + len(rep)
         return text
     def apply(self, text):
         text = self._split(text)
@@ -145,11 +157,8 @@ def read_tab_file(path, encrypted=0, debug=0):
     file = builtin_open(path)
     lineno = 0
     buffer = []
-    while 1:
-        line = file.readline()
-        if not line:
-            break
-        lineno = lineno + 1
+    for line in file:
+        lineno += 1
         if line[-2:] == "\r\n":
             line = line[:-2]
         elif line[-1] in "\r\n":
@@ -157,13 +166,13 @@ def read_tab_file(path, encrypted=0, debug=0):
         if encrypted:
             line = string.join(decrypt(decrypt(line)), "")
         try:
-            line = kanjilib.sjis2euc(line)
-        except kanjilib.error, e:
+            line = unicode(line, 'Shift_JIS').encode('EUC-JP')
+        except UnicodeError, e:
             if debug & 4:
                 print "satori.py: %s in %s (line %d)" % (e, path, lineno)
             continue
         try:
-            old, new = string.split(line, "\t")
+            old, new = line.split("\t")
         except ValueError:
             if debug & 4:
                 print "satori.py: invalid line in %s (line %d)" % (path, lineno)
@@ -224,11 +233,8 @@ class Parser:
     def read_file(self, file, path=None, encrypted=0):
         lineno = 0
         linelist = None
-        while 1:
-            line = file.readline()
-            if not line:
-                break
-            lineno = lineno + 1
+        for line in file:
+            lineno += 1
             if line[-2:] == "\r\n":
                 line = line[:-2]
             elif line[-1] in "\r\n":
@@ -236,8 +242,8 @@ class Parser:
             if encrypted:
                 line = string.join(decrypt(decrypt(line)), "")
             try:
-                line = kanjilib.sjis2euc(line)
-            except kanjilib.error, e:
+                line = unicode(line, 'Shift_JIS').encode('EUC-JP')
+            except UnicodeError, e:
                 if self.debug & 4:
                     if path is None:
                         print "satori.py: %s (line %d)" % (e, lineno)
@@ -247,7 +253,7 @@ class Parser:
             if line[:2] == "":
                 continue
             ### FIXME: զզ...ա
-            pos = string.find(line, "")
+            pos = line.find("")
             if pos > 0:
                 line = line[:pos]
             if line[:2] == "":
@@ -271,9 +277,9 @@ class Parser:
         eventtalk = 0
         for key in self.talk.keys():
             number = len(self.talk[key])
-            talk = talk + number
+            talk += number
             if key[:2] == 'On':
-                eventtalk = eventtalk + number
+                eventtalk += number
         self.count['Talk'] = talk
         self.count['EventTalk'] = eventtalk
         if self.talk.has_key(''):
@@ -284,7 +290,7 @@ class Parser:
         self.count['Words'] = len(self.word)
         word = 0
         for key in self.word.keys():
-            word = word + len(self.word[key])
+            word += len(self.word[key])
         self.count['Word'] = word
         self.count['Anchor'] = len(self.anchor_list)
         self.count['Variable'] = len(self.variable)
@@ -295,10 +301,10 @@ class Parser:
         while i < j:
             if line[i] < "\x80":
                 buffer.append(line[i])
-                i = i + 1
+                i += 1
             else:
                 buffer.append(line[i:i+2])
-                i = i + 2
+                i += 2
         return buffer
     def parse_talk(self, linelist):
         lineno = linelist[0]
@@ -313,13 +319,14 @@ class Parser:
         close = 0
         for n in range(2, len(linelist)):
             line = self.split(linelist[n])
-            open = open + line.count("")
-            close = close + line.count("")
+            open += line.count("")
+            close += line.count("")
             if open > 0 and open != close:
                 if n == len(linelist) - 1:
-                    print "satori.py: syntax error (unbalanced parens)"
+                    if self.debug & 4:
+                        print "satori.py: syntax error (unbalanced parens)"
                 else:
-                    prev = prev + linelist[n]
+                    prev += linelist[n]
                     continue 
             else:
                 open = 0
@@ -365,13 +372,14 @@ class Parser:
         close = 0
         for n in range(2, len(linelist)):
             line = self.split(linelist[n])
-            open = open + line.count("")
-            close = close + line.count("")
+            open += line.count("")
+            close += line.count("")
             if open > 0 and open != close:
                 if n == len(linelist) - 1:
-                    print "satori.py: syntax error (unbalanced parens)"
+                    if self.debug & 4:
+                        print "satori.py: syntax error (unbalanced parens)"
                 else:
-                    prev = prev + linelist[n]
+                    prev += linelist[n]
                     continue 
             else:
                 open = 0
@@ -400,11 +408,11 @@ class Parser:
             return None
         name = self.parse_word(line[1:n])
         if line[n] == "":
-            n = n + 1
+            n += 1
         else:
             sep = line[n]
             while n < len(line) and line[n] == sep:
-                n = n + 1
+                n += 1
         value = self.parse_expression(line[n:])
         if not name in self.variable:
             self.variable.append(name)
@@ -418,7 +426,7 @@ class Parser:
             n = len(line)
         target = self.parse_word(line[1:n])
         while n < len(line) and line[n] == "\t":
-            n = n + 1
+            n += 1
         if n < len(line):
             condition = self.parse_expression(line[n:])
         else:
@@ -435,7 +443,7 @@ class Parser:
             n = len(line)
         label = self.parse_word(line[1:n])
         while n < len(line) and line[n] == "\t":
-            n = n + 1
+            n += 1
         if n < len(line):
             id = self.parse_word(line[n:])
         else:
@@ -455,7 +463,7 @@ class Parser:
                     text = []
                 buffer.append([NODE_SIDE, [line.pop(0)]])
             elif line[0] == "":
-                self.parenthesis = self.parenthesis + 1
+                self.parenthesis += 1
                 if text:
                     buffer.append([NODE_TEXT, text])
                     text = []
@@ -468,7 +476,7 @@ class Parser:
                         for sep in ['\1', ',', '', '']:
                             buf = []
                             for item in list:
-                                buf.extend(string.split(item, sep))
+                                buf.extend(item.split(sep))
                             list = buf
                         if list[0] in ['ñɲ', 'sync', 'loop', 'call', 'set', 'remember']:
                             function = list[0]
@@ -851,7 +859,8 @@ class Satori:
             if name in ["λե0", "λե1",
                         "ǥեȥե0", "ǥեȥե1"]:
                 continue
-            line = "%s\t%s" % (kanjilib.euc2sjis(name), kanjilib.euc2sjis(value))
+            line = "%s\t%s" % (unicode(name, 'EUC-JP').encode('Shift_JIS'),
+                               unicode(value, 'EUC-JP').encode('Shift_JIS'))
             if encrypted:
                 line = string.join(encrypt(encrypt(line)), "")
             file.write(line)
@@ -859,7 +868,8 @@ class Satori:
         for side in [0, 1]:
             name = "ǥեȥե%d" % side
             value = self.to_zenkaku("%d" % self.default_surface[side])
-            line = "%s\t%s" % (kanjilib.euc2sjis(name), kanjilib.euc2sjis(value))
+            line = "%s\t%s" % (unicode(name, 'EUC-JP').encode('Shift_JIS'),
+                               unicode(value, 'EUC-JP').encode('Shift_JIS'))
             if encrypted:
                 line = string.join(encrypt(encrypt(line)), "")
             file.write(line)
@@ -867,28 +877,32 @@ class Satori:
         for side in [0, 1]:
             name = "λե%d" % side
             value = self.to_zenkaku("%d" % self.current_surface[side])
-            line = "%s\t%s" % (kanjilib.euc2sjis(name), kanjilib.euc2sjis(value))
+            line = "%s\t%s" % (unicode(name, 'EUC-JP').encode('Shift_JIS'),
+                               unicode(value, 'EUC-JP').encode('Shift_JIS'))
             if encrypted:
                 line = string.join(encrypt(encrypt(line)), "")
             file.write(line)
             file.write("\r\n")
         name = "ư"
         value = self.to_zenkaku("%d" % self.runcount)
-        line = "%s\t%s" % (kanjilib.euc2sjis(name), kanjilib.euc2sjis(value))
+        line = "%s\t%s" % (unicode(name, 'EUC-JP').encode('Shift_JIS'),
+                           unicode(value, 'EUC-JP').encode('Shift_JIS'))
         if encrypted:
             line = string.join(encrypt(encrypt(line)), "")
         file.write(line)
         file.write("\r\n")
         for name in self.timer.keys():
             value = self.to_zenkaku(self.timer[name])
-            line = "%s\t%s" % (kanjilib.euc2sjis(name), kanjilib.euc2sjis(value))
+            line = "%s\t%s" % (unicode(name, 'EUC-JP').encode('Shift_JIS'),
+                               unicode(value, 'EUC-JP').encode('Shift_JIS'))
             if encrypted:
                 line = string.join(encrypt(encrypt(line)), "")
             file.write(line)
             file.write("\r\n")
         for name in self.reserved_talk.keys():
             value = self.to_zenkaku(self.reserved_talk[name])
-            line = "%s\t%s" % (kanjilib.euc2sjis("" + value + "ܤΥȡ"), kanjilib.euc2sjis(name))
+            line = "%s\t%s" % (unicode("" + value + "ܤΥȡ", 'EUC-JP').encode('Shift_JIS'),
+                               unicode(name, 'EUC-JP').encode('Shift_JIS'))
             if encrypted:
                 line = string.join(encrypt(encrypt(line)), "")
             file.write(line)
@@ -925,6 +939,7 @@ class Satori:
                            ref4=None, ref5=None, ref6=None, ref7=None):
         self.event = event
         self.reference = [ref0, ref1, ref2, ref3, ref4, ref5, ref6, ref7]
+        tail = "\e"
         if event == "OnUpdateReady":
             try:
                 ref0 = str(int(ref0) + 1)
@@ -936,7 +951,7 @@ class Satori:
             count, timestamp = self.mouse_move_count.get(key, (0, 0))
             if int(time.time() - timestamp) > self.touch_timeout:
                 count = 0
-            count = count + 1
+            count += 1
             if count >= self.touch_threshold:
                 event = "%s%sʤǤ" % (str(ref3), str(ref4))
                 count = 0
@@ -946,15 +961,15 @@ class Satori:
             count, timestamp = self.mouse_wheel_count.get(key, (0, 0))
             if int(time.time() - timestamp) > 2:
                 count = 0
-            count = count + 1
+            count += 1
             if count >= 2:
                 event = "%s%s" % (str(ref3), str(ref4))
                 count = 0
             self.mouse_wheel_count[key] = (count, time.time())
         elif event == "OnSecondChange":
-            self.silent_time = self.silent_time + 1
+            self.silent_time += 1
             if self.save_interval > 0:
-               self.save_timer = self.save_timer - 1
+               self.save_timer -= 1
                if self.save_timer <= 0:
                    self.save_database()
                    self.save_timer = self.save_interval
@@ -963,7 +978,7 @@ class Satori:
                 if self.random_talk == 0:
                     self.reset_random_talk_interval()
                 elif self.random_talk > 0:
-                    self.random_talk = self.random_talk - 1
+                    self.random_talk -= 1
                     if self.random_talk == 0:
                         event = self.get_reserved_talk()
                         if event:
@@ -1021,15 +1036,16 @@ class Satori:
                     self.script_history.append(script)
                     return script
             if event in ["OnClose", "OnGhostChanging"]:
-                script = self.get_script("OnSatoriClose")
+                if event == "OnClose":
+                    tail = r"\-\e"
+                script = self.get_script("OnSatoriClose", tail=tail)
                 if script:
-                    self.get_script(event)
                     self.script_history.pop(0)
                     self.script_history.append(script)
                     return script
             if not self.talk.has_key(event):
                 event = self.EVENT_MAP[event]
-        script = self.get_script(event)
+        script = self.get_script(event, tail=tail)
         if script:
             self.script_history.pop(0)
             self.script_history.append(script)
@@ -1048,14 +1064,13 @@ class Satori:
     def getstring(self, name):
         word = self.word.get(name)
         if word is not None:
-            return self.expand(whrandom.choice(word))
+            return self.expand(random.choice(word))
         return None
     # internal
     def get_reserved_talk(self):
         reserved = None
         for key in self.reserved_talk.keys():
-            timer = self.reserved_talk[key]
-            self.reserved_talk[key] = timer - 1
+            self.reserved_talk[key] -= 1
             if self.reserved_talk[key] <= 0:
                 reserved = key
         if reserved is not None:
@@ -1083,11 +1098,11 @@ class Satori:
             match = self.re_reservation.match(name)
             number = self.to_integer(match.group(1))
             if match.group(4) is not None:
-                number = whrandom.randint(number, self.to_integer(match.group(4)))
+                number = random.randint(number, self.to_integer(match.group(4)))
             while 1:
                 for key in self.reserved_talk:
                     if self.reserved_talk[key] == number:
-                        number = number + 1
+                        number += 1
                         break
                 else:
                     break
@@ -1099,7 +1114,7 @@ class Satori:
             while 1:
                 for key in self.reserved_talk:
                     if self.reserved_talk[key] == number:
-                        number = number + 1
+                        number += 1
                         break
                 else:
                     break
@@ -1169,20 +1184,27 @@ class Satori:
         return None
     def change_folder(self):
         value = self.variable.get("ե")
-        list = string.split(value, ',')
+        list = value.split(',')
         self.parser = Parser()
         self.parser.set_saori(self.saori_function.keys())
+        for path in list_dict(self.satori_dir):
+            filename = os.path.basename(path)
+            if filename == "replace.txt":
+                self.parser.load_replace_file(path)
+            elif filename == "replace_after.txt":
+                self.load_replace_file(path)
         buffer = []
         for dir in list:
-            dict_dir = os.path.join(self.satori_dir, string.lower(dir))
+            dict_dir = os.path.join(self.satori_dir, dir.lower())
             if not os.path.isdir(dict_dir):
-                print "satori.py: cannot read", dict_dir
+                if debug & 4:
+                    print "satori.py: cannot read", dict_dir
                 continue
             for path in list_dict(dict_dir):
                 filename = os.path.basename(path)
-                if filename == "replace.txt":
+                if filename == "replace.txt": ## XXX
                     self.parser.load_replace_file(path)
-                elif filename == "replace_after.txt":
+                elif filename == "replace_after.txt": ## XXX
                     self.load_replace_file(path)
                 elif filename in ["satori_conf.txt", "satori_conf.sat"]:
                     pass
@@ -1206,7 +1228,7 @@ class Satori:
         else:
             rate = min(max(rate, 1), 100) / 100.0
         diff = int(interval * rate)
-        self.random_talk = whrandom.randint(interval - diff, interval + diff)
+        self.random_talk = random.randint(interval - diff, interval + diff)
     def add_timer(self, name, value):
         count = self.to_integer(value)
         if count is None or count == 0:
@@ -1216,7 +1238,7 @@ class Satori:
             self.timer[name] = count
     def delete_all_timers(self):
         self.timer = {}
-    def get_script(self, name):
+    def get_script(self, name, head=r"\1", tail=r"\e"):
         if self.reset_surface:
             self.current_reset_surface = [1, 1]
         else:
@@ -1224,7 +1246,7 @@ class Satori:
         script = self.get(name, default=None)
         if script is not None and script and script != "\\n":
             ##print 'make("%s")' % script
-            return self.make(r"\1" + script + r"\e")
+            return self.make(head + script + tail)
         return None
     def get_url_list(self, name):
         self.url_list[name] = []
@@ -1238,30 +1260,30 @@ class Satori:
             j = 0
             while j < len(nodelist):
                 node = nodelist[j]
-                j = j + 1
+                j += 1
                 if node[0] == NODE_TEXT:
                     if node[1] == ['\\n']:
                         break
                     else:
-                        title = title + string.join(node[1], "")
+                        title += string.join(node[1], "")
                 else:
                    pass
             if not title:
                 continue
             if title == '-':
                 if url_list:
-                    url_list = url_list + chr(2)
-                url_list = url_list + title + chr(1)
+                    url_list += chr(2)
+                url_list += title + chr(1)
                 continue
             url = ""
             while j < len(nodelist):
                 node = nodelist[j]
-                j = j + 1
+                j += 1
                 if node[0] == NODE_TEXT:
                     if node[1] == ['\\n']:
                         break
                     else:
-                        url = url + string.join(node[1], "")
+                        url += string.join(node[1], "")
                 else:
                    pass
             if not url:
@@ -1269,12 +1291,12 @@ class Satori:
             bannar = ""
             while j < len(nodelist):
                 node = nodelist[j]
-                j = j + 1
+                j += 1
                 if node[0] == NODE_TEXT:
                     if node[1] == ['\\n']:
                         break
                     else:
-                        bannar = bannar + string.join(node[1], "")
+                        bannar += string.join(node[1], "")
                 else:
                    pass
             if len(nodelist[j:]) > 0:
@@ -1283,8 +1305,8 @@ class Satori:
                 script = None
             self.url_list[name].append([title, url, bannar, script])
             if url_list:
-                url_list = url_list + chr(2)
-            url_list = url_list + title + chr(1) + url + chr(1) + bannar
+                url_list += chr(2)
+            url_list += title + chr(1) + url + chr(1) + bannar
         if not url_list:
             url_list = None
         return url_list
@@ -1402,7 +1424,7 @@ class Satori:
                 i = match.end()
                 continue
             if script[i] == "[":
-                pos = string.find(script, "]", i)
+                pos = script.find("]", i)
                 if pos > i:
                     buffer.append(script[i:pos+1])
                     i = pos + 1
@@ -1413,25 +1435,25 @@ class Satori:
                 i = match.end()
             elif script[i] < "\x80":
                 buffer.append(script[i])
-                n = n + 3
-                i = i + 1
+                n += 3
+                i += 1
             else:
                 buffer.append(script[i:i+2])
-                n = n + 6
-                i = i + 2
+                n += 6
+                i += 2
         return string.join(buffer, "")
     def make_wait(self, ms):
         buffer = []
         n = (ms + 25) * self.wait_percent / 100 / 50
         while n > 0:
             buffer.append(r"\w%d" % min(n, 9))
-            n = n - 9
+            n -= 9
         return buffer
     def get(self, name, default=""):
         list = self.talk.get(name)
         if list is None:
             return default
-        return self.expand(whrandom.choice(list))
+        return self.expand(random.choice(list))
     def expand(self, nodelist, caller_history=None, side=1):
         if nodelist is None:
             return ""
@@ -1571,10 +1593,10 @@ class Satori:
                     operand = self.to_integer(operand_str)
                     if node[i] == "-":
                         if value is None or operand is None:
-                            value_str = string.replace(value_str, operand_str, "")
+                            value_str = value_str.replace(operand_str, "")
                             value = None
                         else:
-                            value = value - operand
+                            value -= operand
                             value_str = self.to_zenkaku(value)
                         continue
                     if value is None:
@@ -1582,7 +1604,7 @@ class Satori:
                     if operand is None:
                         operand = 0
                     if node[i] == "+":
-                        value = value + operand
+                        value += operand
                     else:
                         raise RuntimeError, "should not reach here"
                 if value is None:
@@ -1600,22 +1622,22 @@ class Satori:
                             value_str = ""
                             value = None
                         elif value is None:
-                            value_str = value_str * operand
+                            value_str *= operand
                             value = None
                         elif operand is None:
-                            value_str = value * operand_str
+                            value_str *= operand_str
                             value = None
                         else:
-                            value = value * operand
+                            value *= operand
                         continue
                     if value is None:
                         value = 0
                     if operand is None:
                         operand = 0
                     if node[i] == "/":
-                        value = value / operand
+                        value /= operand
                     elif node[i] == "%":
-                        value = value % operand
+                        value %= operand
                     else:
                         raise RuntimeError, "should not reach here"
                 if value is None:
@@ -1630,7 +1652,7 @@ class Satori:
                     operand = self.to_integer(self.expand(node[i]))
                     if operand is None:
                         operand = 0
-                    value = value ** operand
+                    value **= operand
                 buffer.append(self.to_zenkaku(value))
             elif node[0] == NODE_UNARY_EXPR:
                 value = self.expand(node[2])
@@ -1646,7 +1668,7 @@ class Satori:
                 buffer.append(self.to_zenkaku(value))
             else:
                 raise RuntimeError, "should not reach here"
-        return string.join(buffer, "")
+        return string.join(buffer, "").strip()
     re_random = re.compile("((||[-+])?(||||||||||[0-9])+)((||[-+])?(||||||||||[0-9])+)")
     re_is_empty = re.compile("(ѿ|ʸ|ñ췲)(.*)פ¸")
     re_n_reserved = re.compile("((||||||||||[0-9])+)ܤΥȡ")
@@ -1654,9 +1676,10 @@ class Satori:
     def get_reference(self, nodelist, history, side):
         key = self.expand(nodelist[1:-1], history)
         if self.word.has_key(key):
-            return self.expand(whrandom.choice(self.word[key]), history, side=side)
+            return self.expand(random.choice(self.word[key]), history, side=side)
         elif self.talk.has_key(key):
-            return self.expand(whrandom.choice(self.talk[key]), side=side)
+            self.reference = [None] * 8
+            return self.expand(random.choice(self.talk[key]), side=1)
         elif self.variable.has_key(key):
             return self.variable[key]
         elif self.timer.has_key(key):
@@ -1668,9 +1691,9 @@ class Satori:
             i = self.to_integer(match.group(1))
             j = self.to_integer(match.group(4))
             if i < j:
-                return self.to_zenkaku(whrandom.randint(i, j))
+                return self.to_zenkaku(random.randint(i, j))
             else:
-                return self.to_zenkaku(whrandom.randint(j, i))
+                return self.to_zenkaku(random.randint(j, i))
         elif self.re_n_reserved.match(key):
             match = self.re_n_reserved.match(key)
             number = self.to_integer(match.group(1))
@@ -1980,7 +2003,7 @@ class Shiori(Satori):
         self.saori_function = {}
         for nodelist in word.get("SAORI", []):
             if nodelist[0][0] == NODE_TEXT:
-                list = string.split(string.join(nodelist[0][1], ''), ',')
+                list = string.join(nodelist[0][1], '').split(',')
                 if len(list) >= 2 and list[0] and list[1]:
                     head, tail = os.path.split(list[1])
                     dir = os.path.join(self.satori_dir, head)
@@ -2005,7 +2028,10 @@ class Shiori(Satori):
         return result
     def show_description(self):
         sys.stdout.write('Shiori: SATORI compatible module for ninix\n'
-                         '        Copyright (C) 2002 by Tamito KAJIYAMA\n')
+                         '        Copyright (C) 2002 by Tamito KAJIYAMA\n'
+                         '        Copyright (C) 2002, 2003 by MATSUMURA Namihiko\n'
+                         '        Copyright (C) 2002-2004 by Shyouzou Sugitani\n'
+                         '        Copyright (C) 2003, 2004 by Shun-ichi TAHARA\n')
     def request(self, req_string):
         if self.folder_change:
             self.change_folder()
@@ -2014,22 +2040,22 @@ class Shiori(Satori):
         req_header = {}
         line = header.readline()
         if line:
-            line = string.strip(line)
-            list = string.split(line)
+            line = line.strip()
+            list = line.split()
             if len(list) >= 2:
-                command = string.strip(list[0])
-                protocol = string.strip(list[1])
+                command = list[0].strip()
+                protocol = list[1].strip()
             while 1:
                 line = header.readline()
                 if not line:
                     break # EOF
-                line = string.strip(line)
+                line = line.strip()
                 if not line:
                     continue
-                colon = string.find(line, ':')
+                colon = line.find(':')
                 if colon >= 0:
-                    key = string.strip(line[:colon])
-                    value = string.strip(line[colon+1:])
+                    key = line[:colon].strip()
+                    value = line[colon+1:].strip()
                     try:
                         value = int(value)
                     except:
@@ -2080,8 +2106,8 @@ class Shiori(Satori):
                  'Sender: Satori\r\n' \
                  'Value: %s\r\n' % result
         if to != None:
-            result = result + 'Reference0: %s\r\n' % to
-        result = result + '\r\n'
+            result += 'Reference0: %s\r\n' % to
+        result += '\r\n'
         return result
     def call_saori(self, name, args, history, side):
         if not self.saori_function.has_key(name) or \
@@ -2098,36 +2124,36 @@ class Shiori(Satori):
         default_args = self.saori_function[name][1:]
         n = len(default_args)
         for i in range(len(default_args)):
-              req = req + 'Argument%s: %s\r\n' % (i, default_args[i])
+              req += 'Argument%s: %s\r\n' % (i, default_args[i])
         for i in range(len(args)):
               argument = args[i]
               if argument:
-                  req = req + 'Argument%s: %s\r\n' % (i + n, argument)
-        req = req + '\r\n'
-        response = self.saori_library.request(self.saori_function[name][0], kanjilib.euc2sjis(req, 'ignore'))
+                  req += 'Argument%s: %s\r\n' % (i + n, argument)
+        req += '\r\n'
+        response = self.saori_library.request(self.saori_function[name][0], unicode(req, 'EUC-JP', 'ignore').encode('Shift_JIS', 'ignore'))
         header = StringIO.StringIO(response)
         line = header.readline()
         if line:
             if line[-1] == '\n':
                 line = line[:-1]
-            line = string.strip(line)
-            pos_space = string.find(line, ' ')
+            line = line.strip()
+            pos_space = line.find(' ')
             if pos_space >= 0:
-                saori_protocol = string.strip(line[:pos_space])
-                saori_statuscode = string.strip(line[pos_space:])
+                saori_protocol = line[:pos_space].strip()
+                saori_statuscode = line[pos_space:].strip()
             while 1:
                 line = header.readline()
                 if not line:
                     break # EOF
                 if line[-1] == '\n':
                     line = line[:-1]
-                line = string.strip(line)
+                line = line.strip()
                 if not line:
                     continue
-                colon = string.find(line, ':')
+                colon = line.find(':')
                 if colon >= 0:
-                    key = string.strip(line[:colon])
-                    value = string.strip(line[colon+1:])
+                    key = line[:colon].strip()
+                    value = line[colon+1:].strip()
                     if key:
                         saori_header.append(key)
                         saori_value[key] = value
@@ -2141,7 +2167,7 @@ class Shiori(Satori):
             name = '' + self.to_zenkaku(i)
             self.variable[name] = saori_value[key]
         if saori_value.has_key('Result'):
-            return kanjilib.sjis2euc(saori_value['Result'], 'ignore')
+            return unicode(saori_value['Result'], 'Shift_JIS', 'ignore').encode('EUC-JP', 'ignore')
         else:
             return ''
 
