@@ -1,9 +1,20 @@
-# Tamito KAJIYAMA <3 July 2001>
-# $Id: prefs.py,v 1.1.1.1 2003/04/11 05:54:31 shy Exp $
+# -*- coding: ascii -*-
+#
+#  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
+#  Copyright (C) 2004 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#
+#  This program is free software; you can redistribute it and/or modify it
+#  under the terms of the GNU General Public License (version 2) as
+#  published by the Free Software Foundation.  It is distributed in the
+#  hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
+#  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+#  PURPOSE.  See the GNU General Public License for more details.
+#
+# $Id: prefs.py,v 1.4 2004/04/13 05:21:59 shy Exp $
+#
 
 import mimetools
 import os
-import string
 import UserDict
 
 import ninix.home
@@ -41,9 +52,9 @@ class Preferences(UserDict.UserDict):
                 pass
         return default
     def getint(self, name, default=None):
-        return self._get(name, default, string.atoi)
+        return self._get(name, default, int)
     def getfloat(self, name, default=None):
-        return self._get(name, default, string.atof)
+        return self._get(name, default, float)
 
 def new_prefs():
     filename = ninix.home.get_preferences()
